@@ -12,6 +12,7 @@ from auto_editor.utils.log import Log, Timer
 from auto_editor.utils.types import (
     MainArgs,
     color,
+    frame_rate,
     margin,
     number,
     resolution,
@@ -143,7 +144,7 @@ def main_options(parser: ArgumentParser) -> ArgumentParser:
         "--frame-rate",
         "-fps",
         "-r",
-        type=number,
+        type=frame_rate,
         help="Set the frame rate for the timeline and output media.",
     )
     parser.add_argument(
@@ -223,19 +224,16 @@ def main_options(parser: ArgumentParser) -> ArgumentParser:
     )
     parser.add_argument("--quiet", "-q", flag=True, help="Display less output.")
     parser.add_argument(
-        "--preview", flag=True, help="Show stats on how the input will be cut and halt."
+        "--preview",
+        "--stats",
+        flag=True,
+        help="Show stats on how the input will be cut and halt.",
     )
     parser.add_argument(
         "--timeline", flag=True, help="Show auto-editor JSON timeline file and halt."
     )
     parser.add_argument("--api", help="Set what version of the timeline to use.")
     parser.add_text("Global Editing Options")
-    parser.add_argument(
-        "--silent-threshold",
-        "-t",
-        type=number,
-        help="Set the volume that frames audio needs to surpass to be marked loud.",
-    )
     parser.add_argument(
         "--frame-margin",
         "--margin",
@@ -361,16 +359,16 @@ def main() -> None:
     if args.video_speed <= 0 or args.video_speed > 99999:
         args.video_speed = 99999
 
-    inputs = valid_input(args.input, ffmpeg, args, log)
+    paths = valid_input(args.input, ffmpeg, args, log)
 
-    if exporting_to_editor and len(inputs) > 1:
+    if exporting_to_editor and len(paths) > 1:
         cmd = []
-        for inp in inputs:
-            cmd.extend(["-i", inp])
+        for path in paths:
+            cmd.extend(["-i", path])
         cmd.extend(
             [
                 "-filter_complex",
-                f"[0:v]concat=n={len(inputs)}:v=1:a=1",
+                f"[0:v]concat=n={len(paths)}:v=1:a=1",
                 "-codec:v",
                 "h264",
                 "-pix_fmt",
@@ -381,9 +379,9 @@ def main() -> None:
             ]
         )
         ffmpeg.run(cmd)
-        inputs = ["combined.mp4"]
+        paths = ["combined.mp4"]
     try:
-        output = edit_media(inputs, ffmpeg, args, temp, log)
+        output = edit_media(paths, ffmpeg, args, temp, log)
 
         if not args.preview and not args.timeline:
             timer.stop()
