@@ -211,10 +211,11 @@ def edit_media(
         preview(timeline, temp, log)
         return None
 
-    if args.export == "json":
+    if out_ext == "json":
         from auto_editor.formats.json import make_json_timeline
 
         make_json_timeline(args.api, output, timeline, log)
+        args.no_open = True
         return output
 
     if args.export == "premiere":
@@ -252,7 +253,7 @@ def edit_media(
         if ctr.allow_audio:
             from auto_editor.render.audio import make_new_audio
 
-            audio_output = make_new_audio(timeline, bar, temp, log)
+            audio_output = make_new_audio(timeline, ffmpeg, bar, temp, log)
 
         if ctr.allow_video:
             if len(timeline.v) > 0:
@@ -278,6 +279,7 @@ def edit_media(
             apply_later,
             ctr,
             output,
+            timeline.timebase,
             args,
             inp,
             temp,
@@ -304,7 +306,7 @@ def edit_media(
                 continue
 
             _c = pad_chunk(chunk, total_frames)
-            vspace, aspace = make_av([clipify(_c, 0, 0)], [inp])
+            vspace, aspace = make_av([clipify(_c, 0)], [inp])
             my_timeline = Timeline(
                 timeline.inputs,
                 timeline.timebase,
