@@ -1,15 +1,16 @@
+from __future__ import annotations
+
 import os.path
+from fractions import Fraction
 from os.path import abspath
+from platform import system
 from shutil import move
 from urllib.parse import quote
-from platform import system
 
-from typing import List, Tuple
+from auto_editor.timeline import Timeline
 
 from .utils import indent, safe_mkdir
 
-from auto_editor.ffwrapper import FileInfo
-
 """
 Premiere Pro uses the Final Cut Pro 7 XML Interchange Format
 
@@ -26,16 +27,10 @@ ANAMORPHIC = "FALSE"
 DEPTH = "16"
 
 
-def get_samplerate(inp: FileInfo) -> str:
-    if len(inp.audios) > 0 and inp.audios[0].samplerate is not None:
-        return inp.audios[0].samplerate
-    return "48000"
-
-
 def fix_url(path: str) -> str:
     if system() == "Windows":
         return "file://localhost/" + quote(abspath(path)).replace("%5C", "/")
-    return "file://localhost" + abspath(path)
+    return f"file://localhost{abspath(path)}"
 
 
 def speedup(speed: float) -> str:
@@ -78,28 +73,35 @@ def speedup(speed: float) -> str:
 
 
 def premiere_xml(
-    inp: FileInfo,
     temp: str,
     output: str,
-    chunks: List[Tuple[int, int, float]],
+    timeline: Timeline,
 ) -> None:
 
+    inp = timeline.inp
+    chunks = timeline.chunks
+
+    if chunks is None:
+        raise ValueError("Timeline too complex")
+
+    fps = timeline.timebase
+    samplerate = timeline.samplerate
+
     audio_file = len(inp.videos) == 0 and len(inp.audios) == 1
 
-    # This is not at all how timebase works in actual media but that's how it works here.
-    fps = inp.gfps
-    timebase = int(fps)
+    # See chart: https://developer.apple.com/library/archive/documentation/AppleApplications/Reference/FinalCutPro_XML/FrameRate/FrameRate.html#//apple_ref/doc/uid/TP30001158-TPXREF103
 
-    if fps == 23.98 or fps == 23.97602397 or fps == 23.976:
+    if fps == 23.98 or fps == 23.976 or fps == Fraction(24000, 1001):
         timebase = 24
         ntsc = "TRUE"
-    elif fps == 29.97 or fps == 29.97002997:
+    elif fps == 29.97 or fps == Fraction(30000, 1001):
         timebase = 30
         ntsc = "TRUE"
     elif fps == 59.94 or fps == 59.94005994:
         timebase = 60
         ntsc = "TRUE"
     else:
+        timebase = int(fps)
         ntsc = "FALSE"
 
     duration = chunks[-1][1]
@@ -120,10 +122,10 @@ def premiere_xml(
 
         for i in range(1, tracks):
             newtrack = os.path.join(fold, f"{i}.wav")
-            move(os.path.join(temp, f"{i}.wav"), newtrack)
+            move(os.path.join(temp, f"0-{i}.wav"), newtrack)
             pathurls.append(fix_url(newtrack))
 
-    width, height = inp.gwidth, inp.gheight
+    width, height = timeline.res
 
     group_name = f"Auto-Editor {'Audio' if audio_file else 'Video'} Group"
 
@@ -242,7 +244,7 @@ def premiere_xml(
                             "\t\t<audio>",
                             "\t\t\t<samplecharacteristics>",
                             f"\t\t\t\t<depth>{DEPTH}</depth>",
-                            f"\t\t\t\t<samplerate>{inp.gsamplerate}</samplerate>",
+                            f"\t\t\t\t<samplerate>{samplerate}</samplerate>",
                             "\t\t\t</samplecharacteristics>",
                             "\t\t\t<channelcount>2</channelcount>",
                             "\t\t</audio>",
@@ -287,7 +289,7 @@ def premiere_xml(
                 "\t<format>",
                 "\t\t<samplecharacteristics>",
                 f"\t\t\t<depth>{DEPTH}</depth>",
-                f"\t\t\t<samplerate>{inp.gsamplerate}</samplerate>",
+                f"\t\t\t<samplerate>{samplerate}</samplerate>",
                 "\t\t</samplecharacteristics>",
                 "\t</format>",
             )
@@ -344,7 +346,7 @@ def premiere_xml(
                             "\t\t<audio>",
                             "\t\t\t<samplecharacteristics>",
                             f"\t\t\t\t<depth>{DEPTH}</depth>",
-                            f"\t\t\t\t<samplerate>{inp.gsamplerate}</samplerate>",
+                            f"\t\t\t\t<samplerate>{samplerate}</samplerate>",
                             "\t\t\t</samplecharacteristics>",
                             "\t\t\t<channelcount>2</channelcount>",
                             "\t\t</audio>",
