@@ -3,6 +3,8 @@ from __future__ import annotations
 from fractions import Fraction
 from typing import List, NamedTuple, Type, Union
 
+import numpy as np
+
 from auto_editor.ffwrapper import FileInfo
 from auto_editor.method import get_has_loud
 from auto_editor.objects import (
@@ -35,7 +37,7 @@ class Clip(NamedTuple):
     src: int
 
 
-def clipify(chunks: Chunks, src: int, start: float) -> list[Clip]:
+def clipify(chunks: Chunks, src: int, start: Fraction = Fraction(0)) -> list[Clip]:
     clips: list[Clip] = []
     # Add "+1" to match how chunks are rendered in 22w18a
     i = 0
@@ -50,7 +52,7 @@ def clipify(chunks: Chunks, src: int, start: float) -> list[Clip]:
 
             if not (len(clips) > 0 and clips[-1].start == round(start)):
                 clips.append(Clip(round(start), dur, offset, chunk[2], src))
-            start += dur / chunk[2]
+            start += Fraction(dur, Fraction(chunk[2]))
             i += 1
 
     return clips
@@ -75,7 +77,8 @@ def make_av(
                 )
                 if len(vclips) == 0:
                     vclips = [[vclip_]]
-                vclips[0].append(vclip_)
+                else:
+                    vclips[0].append(vclip_)
         if len(inp.audios) > 0:
             for clip in clips:
                 for a, _ in enumerate(inp.audios):
@@ -99,14 +102,14 @@ def make_layers(
     add_in: list[list[str]],
     mark_silent: list[list[str]],
     mark_loud: list[list[str]],
-    set_speed_for_range: list[tuple[float, str, str]],
+    speed_range: list[tuple[float, str, str]],
     silent_speed: float,
     loud_speed: float,
     bar: Bar,
     temp: str,
     log: Log,
 ) -> tuple[Chunks, VSpace, ASpace]:
-    start = 0.0
+    start = Fraction(0)
     all_clips: list[list[Clip]] = []
     all_chunks: list[Chunks] = []
 
@@ -137,27 +140,40 @@ def make_layers(
         # Remove small clips/cuts created by applying other rules.
         has_loud = cook(has_loud, min_clip, min_cut)
 
-        speed_list = has_loud.astype(float)
-        del has_loud
+        # Setup for handling custom speeds
+        has_loud = has_loud.astype(np.uint)
         del has_loud_length
 
-        # WARN: This breaks if speed is allowed to be 0
-        speed_list[speed_list == 1] = loud_speed
-        speed_list[speed_list == 0] = silent_speed
+        speed_map = [silent_speed, loud_speed]
+        speed_hash = {
+            0: silent_speed,
+            1: loud_speed,
+        }
+
+        def get_speed(speed: float) -> int:
+            if speed in speed_map:
+                return speed_map.index(speed)
+            speed_map.append(speed)
+            speed_hash[len(speed_map) - 1] = speed
+            return len(speed_map) - 1
 
         if len(cut_out) > 0:
-            speed_list = set_range(speed_list, cut_out, tb, 99999, log)
+            index = get_speed(99999)
+            has_loud = set_range(has_loud, cut_out, tb, index, log)
 
         if len(add_in) > 0:
-            speed_list = set_range(speed_list, add_in, tb, loud_speed, log)
+            # Set speed index to 'loud_speed'
+            has_loud = set_range(has_loud, add_in, tb, 1, log)
 
-        for item in set_speed_for_range:
-            speed_list = set_range(speed_list, [list(item[1:])], tb, item[0], log)
+        for item in speed_range:
+            index = get_speed(item[0])
+            has_loud = set_range(has_loud, [list(item[1:])], tb, index, log)
 
-        _chunks = chunkify(speed_list)
-        all_chunks.append(_chunks)
-        all_clips.append(clipify(_chunks, i, start))
-        start += round(chunks_len(_chunks))
+        chunks = chunkify(has_loud, speed_hash)
+
+        all_chunks.append(chunks)
+        all_clips.append(clipify(chunks, i, start))
+        start += round(chunks_len(chunks))
 
     vclips, aclips = make_av(all_clips, inputs)
     return merge_chunks(all_chunks), vclips, aclips
