@@ -1,6 +1,7 @@
 # type: ignore
 from __future__ import annotations
 
+import json
 import logging
 import os
 import platform
@@ -8,12 +9,11 @@ import shutil
 import subprocess
 import sys
 from dataclasses import dataclass, field
+from fractions import Fraction
 from time import perf_counter
 from typing import Callable, NoReturn
-from fractions import Fraction
 
 import av
-import numpy as np
 
 from auto_editor.vanparse import ArgumentParser
 
@@ -93,38 +93,6 @@ def check_for_error(cmd: list[str], match=None) -> None:
         raise Exception("Program should not respond with a code 0.")
 
 
-def make_np_list(in_file: str, compare_file: str, the_speed: float) -> None:
-    from auto_editor.render.tsm.phasevocoder import phasevocoder
-    from auto_editor.wavfile import read
-
-    _, sped_chunk = read(in_file)
-    channels = 2
-
-    spedup_audio = phasevocoder(channels, the_speed, sped_chunk)
-    loaded = np.load(compare_file)
-
-    if not np.array_equal(spedup_audio, loaded["a"]):
-        if spedup_audio.shape == loaded["a"].shape:
-            print(f"Both shapes ({spedup_audio.shape}) are same")
-        else:
-            print(spedup_audio.shape)
-            print(loaded["a"].shape)
-
-        result = np.subtract(spedup_audio, loaded["a"])
-
-        print(f"result non-zero: {np.count_nonzero(result)}")
-        print(f"len of spedup_audio: {len(spedup_audio)}")
-
-        print(
-            np.count_nonzero(result) / spedup_audio.shape[0],
-            "difference between arrays",
-        )
-
-        raise Exception(f"file {compare_file} doesn't match array.")
-
-    # np.savez_compressed(out_file, a=spedup_audio)
-
-
 class Tester:
     def __init__(self, args: TestArgs) -> None:
         self.passed_tests = 0
@@ -202,20 +170,6 @@ def main(sys_args: list[str] | None = None):
     def parser_test():
         check_for_error(["example.mp4", "--video-speed"], "needs argument")
 
-    def tsm_1a5_test():
-        make_np_list(
-            "resources/wav/example-cut-s16le.wav",
-            "resources/data/example_1.5_speed.npz",
-            1.5,
-        )
-
-    def tsm_2a0_test():
-        make_np_list(
-            "resources/wav/example-cut-s16le.wav",
-            "resources/data/example_2.0_speed.npz",
-            2,
-        )
-
     def info():
         run_program(["info", "example.mp4"])
         run_program(["info", "resources/only-video/man-on-green-screen.mp4"])
@@ -241,6 +195,7 @@ def main(sys_args: list[str] | None = None):
         with av.open("example_ALTERED.mp4") as cn:
             video = cn.streams.video[0]
             assert video.average_rate == 30
+            assert video.time_base == Fraction(1, 30)
             assert video.width == 1280
             assert video.height == 720
             assert video.codec.name == "mpeg4"
@@ -251,6 +206,7 @@ def main(sys_args: list[str] | None = None):
         with av.open("example_ALTERED.mp4") as cn:
             video = cn.streams.video[0]
             assert video.average_rate == 30
+            assert video.time_base == Fraction(1, 30)
             assert video.width == 1280
             assert video.height == 720
             assert video.codec.name == "h264"
@@ -263,6 +219,16 @@ def main(sys_args: list[str] | None = None):
     def high_speed_test():
         run_program(["example.mp4", "--video-speed", "99998"])
 
+    # Issue #288
+    def expand_chunks():
+        run_program(
+            ["example.mp4", "--silent-speed", "1", "-o", "out.json"]
+        )
+        with open("out.json") as file:
+            api = json.load(file)
+        assert len(api["chunks"]) > 4, "Chunks should not combine"
+        os.remove("out.json")
+
     # Issue #184
     def unit_tests():
         run_program(
@@ -275,6 +241,10 @@ def main(sys_args: list[str] | None = None):
         run_program(["example.mp4", "--sample_rate", "44.1 kHz"])
         run_program(["example.mp4", "--edit", "audio:threshold=4%"])
 
+
+    def video_speed():
+        run_program(["example.mp4", "--video-speed", "1.5"])
+
     def backwards_range_test():
         """
         Cut out the last 5 seconds of a media file by using negative number in the
@@ -538,6 +508,7 @@ def main(sys_args: list[str] | None = None):
         with av.open("example_ALTERED.mp4", "r") as cn:
             video = cn.streams.video[0]
             assert video.average_rate == 15
+            assert video.time_base == Fraction(1, 15)
             dur = float(video.duration * video.time_base)
             assert dur - 17.33333333333333333333333 < 3
 
@@ -545,6 +516,7 @@ def main(sys_args: list[str] | None = None):
         with av.open("example_ALTERED.mp4", "r") as cn:
             video = cn.streams.video[0]
             assert video.average_rate == 20
+            assert video.time_base == Fraction(1, 20)
             dur = float(video.duration * video.time_base)
             assert dur - 17.33333333333333333333333 < 2
 
@@ -552,6 +524,7 @@ def main(sys_args: list[str] | None = None):
         with av.open("example_ALTERED.mp4", "r") as cn:
             video = cn.streams.video[0]
             assert video.average_rate == 60
+            assert video.time_base == Fraction(1, 60)
             dur = float(video.duration * video.time_base)
             assert dur - 17.33333333333333333333333 < 0.3
 
@@ -658,9 +631,6 @@ def main(sys_args: list[str] | None = None):
 
     tests = []
 
-    if args.category in ("unit", "all"):
-        tests.extend([tsm_1a5_test, tsm_2a0_test])
-
     if args.category in ("api", "all"):
         tests.append(read_api_0_1)
 
@@ -670,6 +640,8 @@ def main(sys_args: list[str] | None = None):
     if args.category in ("cli", "all"):
         tests.extend(
             [
+                video_speed,
+                expand_chunks,
                 SAR,
                 yuv442p,
                 obj_makes_video,
