@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 import re
 from dataclasses import dataclass, field
-from typing import List, Literal, Optional, Tuple, Union
+from fractions import Fraction
+from typing import Literal, Tuple, Type, Union
 
 
-def _comma_coerce(name: str, val: str, num_args: int) -> List[str]:
+def _comma_coerce(name: str, val: str, num_args: int) -> list[str]:
     vals = val.strip().split(",")
     if num_args > len(vals):
         raise TypeError(f"Too few arguments for {name}.")
@@ -12,15 +15,17 @@ def _comma_coerce(name: str, val: str, num_args: int) -> List[str]:
     return vals
 
 
-def _split_num_str(val: str) -> Tuple[float, str]:
-    NUM_CHARS = {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9", " ", ".", "-"}
+def _split_num_str(val: str | float) -> tuple[float, str]:
+    if isinstance(val, (float, int)):
+        return val, ""
+
+    NUM_CHARS = {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "_", " ", ".", "-"}
     index = 0
     for char in val:
         if char not in NUM_CHARS:
             break
         index += 1
     num, unit = val[:index], val[index:]
-
     try:
         float(num)
     except ValueError:
@@ -28,35 +33,73 @@ def _split_num_str(val: str) -> Tuple[float, str]:
     return float(num), unit
 
 
-def _unit_check(unit: str, allowed_units: Tuple[str, ...]) -> None:
+def _unit_check(unit: str, allowed_units: tuple[str, ...]) -> None:
     if unit not in allowed_units:
         raise TypeError(f"Unknown unit: '{unit}'")
 
 
-Chunk = Tuple[int, int, float]
-Chunks = List[Chunk]
+# Numbers: 0, 1, 2, 3, ...
+def natural(val: str | float) -> int:
+    num, unit = _split_num_str(val)
+    if unit != "":
+        raise TypeError(f"'{val}': Natural does not allow units.")
+    if num < 0:
+        raise TypeError(f"'{val}': Natural cannot be negative.")
+    if not isinstance(num, int) and not num.is_integer():
+        raise TypeError(f"'{val}': Natural must be an integer.")
+    return int(num)
 
 
-def number(val: Union[str, float]) -> float:
-    if not isinstance(val, str):
-        return val
+def number(val: str | float) -> float:
+    if isinstance(val, str) and "/" in val:
+        nd = val.split("/")
+        if len(nd) != 2:
+            raise TypeError(f"'{val}': One divisor allowed.")
+        vs = []
+        for v in nd:
+            try:
+                vs.append(int(v))
+            except ValueError:
+                raise TypeError(f"'{val}': Numerator and Denominator must be integers.")
+        if vs[1] == 0:
+            raise TypeError(f"'{val}': Denominator must not be zero.")
+        return vs[0] / vs[1]
 
     num, unit = _split_num_str(val)
-    _unit_check(unit, ("%", ""))
     if unit == "%":
         return num / 100
+    _unit_check(unit, ("",))
     return num
 
 
+def threshold(val: str | float) -> float:
+    num = number(val)
+    if num > 1 or num < 0:
+        raise TypeError(f"'{val}': Threshold must be between 0 and 1 (0%-100%)")
+    return num
+
+
+def frame_rate(val: str) -> Fraction:
+    if val == "ntsc":
+        return Fraction(30000, 1001)
+    if val == "ntsc_film":
+        return Fraction(24000, 1001)
+    if val == "pal":
+        return Fraction(25)
+    if val == "film":
+        return Fraction(24)
+    return Fraction(number(val))
+
+
 def sample_rate(val: str) -> int:
     num, unit = _split_num_str(val)
-    if unit == "kHz":
-        return int(num * 1000)
+    if unit in ("kHz", "KHz"):
+        return natural(num * 1000)
     _unit_check(unit, ("", "Hz"))
-    return int(num)
+    return natural(num)
 
 
-def time(val: str) -> Union[int, str]:
+def time(val: str) -> int | str:
     num, unit = _split_num_str(val)
     if unit in ("s", "sec", "secs", "second", "seconds"):
         return str(num)
@@ -66,7 +109,7 @@ def time(val: str) -> Union[int, str]:
         return str(num * 3600)
 
     _unit_check(unit, ("", "f", "frame", "frames"))
-    if not num.is_integer():
+    if not isinstance(num, int) and not num.is_integer():
         raise TypeError(f"'{val}': Frame unit doesn't accept non-ints.")
     return int(num)
 
@@ -90,12 +133,13 @@ def margin(val: str) -> Margin:
     return time(vals[0]), time(vals[1])
 
 
-def time_range(val: str) -> List[str]:
+def time_range(val: str) -> list[str]:
     return _comma_coerce("time_range", val, 2)
 
 
-def speed_range(val: str) -> List[str]:
-    return _comma_coerce("speed_range", val, 3)
+def speed_range(val: str) -> tuple[float, str, str]:
+    a = _comma_coerce("speed_range", val, 3)
+    return number(a[0]), a[1], a[2]
 
 
 Align = Literal["left", "center", "right"]
@@ -117,7 +161,7 @@ Stream = Union[int, Literal["all"]]
 def stream(val: str) -> Stream:
     if val == "all":
         return "all"
-    return int(val)
+    return natural(val)
 
 
 def color(val: str) -> str:
@@ -144,38 +188,55 @@ def color(val: str) -> str:
     raise ValueError(f"Invalid Color: '{color}'")
 
 
+def resolution(val: str | None) -> tuple[int, int] | None:
+    if val is None:
+        return None
+    vals = val.strip().split(",")
+    if len(vals) != 2:
+        raise TypeError(f"'{val}': Resolution takes two numbers")
+
+    return natural(vals[0]), natural(vals[1])
+
+
+def pos(val: tuple[float | str, int]) -> int:
+    num, unit = _split_num_str(val[0])
+    if unit == "%":
+        return round((num / 100) * val[1])
+    _unit_check(unit, ("",))
+    return round(num)
+
+
 @dataclass
 class MainArgs:
-    add_text: List[str] = field(default_factory=list)
-    add_rectangle: List[str] = field(default_factory=list)
-    add_ellipse: List[str] = field(default_factory=list)
-    add_image: List[str] = field(default_factory=list)
+    pool: list[tuple[str, str]] = field(default_factory=list)
     yt_dlp_location: str = "yt-dlp"
-    download_format: Optional[str] = None
-    output_format: Optional[str] = None
-    yt_dlp_extras: Optional[str] = None
+    download_format: str | None = None
+    output_format: str | None = None
+    yt_dlp_extras: str | None = None
     video_codec: str = "auto"
     audio_codec: str = "auto"
     video_bitrate: str = "10m"
     audio_bitrate: str = "unset"
     video_quality_scale: str = "unset"
     scale: float = 1.0
-    extras: Optional[str] = None
+    extras: str | None = None
     no_seek: bool = False
-    cut_out: List[str] = field(default_factory=list)
-    add_in: List[str] = field(default_factory=list)
-    mark_as_loud: List[str] = field(default_factory=list)
-    mark_as_silent: List[str] = field(default_factory=list)
-    set_speed_for_range: List[str] = field(default_factory=list)
-    frame_rate: Optional[float] = None
-    sample_rate: Optional[int] = None
+    cut_out: list[list[str]] = field(default_factory=list)
+    add_in: list[list[str]] = field(default_factory=list)
+    mark_as_loud: list[list[str]] = field(default_factory=list)
+    mark_as_silent: list[list[str]] = field(default_factory=list)
+    set_speed_for_range: list[tuple[float, str, str]] = field(default_factory=list)
+    frame_rate: Fraction | None = None
+    sample_rate: int | None = None
+    resolution: tuple[int, int] | None = None
     background: str = "#000"
     edit_based_on: str = "audio"
     keep_tracks_separate: bool = False
     export: str = "default"
+    player: str | None = None
     no_open: bool = False
-    temp_dir: Optional[str] = None
-    ffmpeg_location: Optional[str] = None
+    temp_dir: str | None = None
+    ffmpeg_location: str | None = None
     my_ffmpeg: bool = False
     progress: str = "modern"
     version: bool = False
@@ -185,15 +246,17 @@ class MainArgs:
     preview: bool = False
     timeline: bool = False
     api: str = "1.0.0"
-    silent_threshold: float = 0.04
     frame_margin: Margin = (6, 6)
     silent_speed: float = 99999.0
     video_speed: float = 1.0
-    min_clip_length: Union[int, str] = 3
-    min_cut_length: Union[int, str] = 6
-    output_file: Optional[str] = None
+    min_clip_length: int | str = 3
+    min_cut_length: int | str = 6
+    output_file: str | None = None
     help: bool = False
-    input: List[str] = field(default_factory=list)
+    input: list[str] = field(default_factory=list)
+
+
+Args = Type[MainArgs]
 
 
 colormap = {
